import 'package:flutter/material.dart';

class SearchTextField extends StatefulWidget {
  const SearchTextField({
    Key? key,
    required this.child,
    required this.suggestions,
  }) : super(key: key);

  final Widget child;
  final List<String> suggestions;

  @override
  State<SearchTextField> createState() => _SearchTextFieldState();
}

class _SearchTextFieldState extends State<SearchTextField> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Search'),
        actions: [
          IconButton(
              icon: const Icon(Icons.search),
              tooltip: 'Ricerca',
              onPressed: () {
                showSearch(
                  context: context,
                  delegate: MySearchDelegate(suggestions: widget.suggestions),
                );
              }),
        ],
      ),
      body: widget.child,
    );
  }
}

class MySearchDelegate extends SearchDelegate {
  MySearchDelegate({
    required this.suggestions,
  });

  final List<String> suggestions;

  @override
  List<Widget>? buildActions(BuildContext context) => [
        ///
        /// Questo bottone cambia il valore presente nella barra, nella stringa vuota
        ///
        IconButton(
          onPressed: () {
            if (query.isEmpty) {
              close(context, null);
            } else {
              query = '';
            }
          },
          icon: const Icon(Icons.clear),
        ),
      ];

  @override
  Widget? buildLeading(BuildContext context) => IconButton(
        ///
        /// Chiude la barra di ricerca
        ///
        onPressed: () {
          close(context, null);
        },
        icon: const Icon(Icons.arrow_back),
      );

  @override
  Widget buildResults(BuildContext context) => Center(
        child: Text(
          query,
          style: const TextStyle(fontSize: 64, fontWeight: FontWeight.w700),
        ),
      );

  @override
  Widget buildSuggestions(BuildContext context) {
    List<String> sugs = suggestions.where((element) {
      final result = element.toLowerCase();
      final input = query.toLowerCase();

      return result.contains(input);
    }).toList();

    return ListView.builder(
      itemCount: sugs.length,
      itemBuilder: (context, index) {
        String sug = sugs[index];
        return ListTile(
          title: Text(sug),
          onTap: () {
            query = sug;
            showResults(context);
          },
        );
      },
    );
  }
}
